<?php

namespace Tests\Auth;

use App\AuthAdapters\AuthAdapterUser;
use App\Mapper\User;
use Doctrine\ODM\MongoDB\DocumentManager;
use SlimAuth\AuthResponse;
use SlimAuth\SlimAuthFacade;
use Tests\BaseUnitTests;

class AuthenticateUserTest extends BaseUnitTests
{
    /**
     * @var DocumentManager
     */
    private $dm;

    public function setUp()
    {
        parent::setUp(); // TODO: Change the autogenerated stub
        $this->dm = $this->_ci->get("database");
    }

    /**
     * @test
     */
    public function shouldCreateUser() {
        $user = new User();
        $user->username = "user";
        $user->password = "nonepassword";

        $this->dm->persist($user);
        $this->dm->flush();

        $this->assertInstanceOf(User::class, $user);
        $this->assertEquals("nonepassword", $user->password);
        print_r($user->id);
    }

    /**
     * @test
     * @depends shouldCreateUser
     */
    public function shouldAuthenticateUser() {

        $adapterAuth = new AuthAdapterUser('user', 'nonepassword');

        $auth = new SlimAuthFacade($adapterAuth, $this->_ci->get('session'));
        $auth->auth();

        $responseAuth = $auth->getAuthResponse();
        $this->assertEquals(AuthResponse::AUTHRESPONSE_SUCCESS, $responseAuth->getMessage()->getCode());
        print_r($responseAuth->getMessage()->getAttrsession());
    }


    /**
     * @test
     * @depends shouldCreateUser
     */
    public function shouldExcludeUser() {
        $userSelect = $this->dm->getRepository(User::class)->findBy(['username' => 'user']);
        $this->dm->remove($userSelect[0]);
        $this->dm->flush();
    }

}